***************
Getting Started
***************

This section covers the usage of Renate from the installation to the training
of a model. The content is intended to explain the basic steps to be taken when creating a new
training pipeline based on Renate.

If your goal is to test multiple Renate algorithms on your dataset or to test a specific algorithm on
multiple datasets and scenarios, you will be better served by the benchmarking functionalities
provided in :doc:`../benchmarking/renate_benchmarks`.

.. toctree::
    :maxdepth: 2

    install
    how_to_renate_config
    how_to_run_training
    output
    supported_algorithms
    avalanche
    shift_detection
